@@ -1,5 +1,6 @@
 import json, os, threading
 
+
 class _PersistentState:
     _instances = {}
 
@@ -40,16 +41,24 @@ class _PersistentState:
 
     def __getattr__(self, name):
         if name.startswith("_"):
-            raise AttributeError(name)
+            raise AttributeError(f"Cannot access private attribute '{name}'")
         if name.endswith("_"):
-            try: 
+            try:
                 return super().__getattribute__(name[:-1])
             except AttributeError:
-                raise AttributeError(f"'{self.__class__.__name__}' object has no attribute '{name}'.\n Notice: Attribute '{name}' is not persistent!")
+                raise AttributeError(
+                    f"'{self.__class__.__name__}' object has no attribute '{name}'.\n Notice: Attribute '{name}' is not persistent!"
+                )
         try:
-            return self._data[name]
+            value = self._data[name]
+            # If it's a dict, return it as a namespace
+            if isinstance(value, dict):
+                return _Namespace(self, name)
+            return value
         except KeyError:
-            raise AttributeError(name)
+            raise AttributeError(
+                f"'{type(self).__name__}' object has no attribute '{name}'"
+            )
 
     def __setattr__(self, name, value):
         if name.startswith("_"):
@@ -92,10 +101,12 @@ class _Namespace:
         if name.startswith("_"):
             raise AttributeError(name)
         if name.endswith("_"):
-            try: 
+            try:
                 return super().__getattribute__(name[:-1])
             except AttributeError:
-                raise AttributeError(f"'{self.__class__.__name__}' object has no attribute '{name}'.\n Notice: Attribute '{name}' is not persistent!")
+                raise AttributeError(
+                    f"'{self.__class__.__name__}' object has no attribute '{name}'.\n Notice: Attribute '{name}' is not persistent!"
+                )
         try:
             return self._root._data[self._key][name]
         except KeyError:
@@ -121,6 +132,4 @@ class PersistentObject(_PersistentState):
         return _Namespace(self, name)
 
 
-
-
 __all__ = ["PersistentObject"]
